"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExecutorImpl = void 0;
const queryExecutor_1 = require("./queryExecutor/queryExecutor");
const domain_1 = require("../../domain");
class ExecutorImpl {
    // eslint-disable-next-line no-useless-constructor
    constructor(connectionFacade, languages, schemaFacade, expressions, helper) {
        this.connectionFacade = connectionFacade;
        this.languages = languages;
        this.schemaFacade = schemaFacade;
        this.expressions = expressions;
        this.helper = helper;
    }
    execute(query, data, options) {
        return __awaiter(this, void 0, void 0, function* () {
            let error;
            let result;
            if (query.includes && query.includes.length > 0) {
                yield this.transaction(options, function (tr) {
                    return __awaiter(this, void 0, void 0, function* () {
                        result = yield tr.execute(query, data);
                    });
                });
            }
            else {
                const queryExecutor = new queryExecutor_1.QueryExecutor(this.connectionFacade, this.languages, this.schemaFacade, this.expressions, options, this.helper, false);
                try {
                    result = yield queryExecutor.execute(query, data);
                }
                catch (_error) {
                    error = _error;
                }
                finally {
                    yield queryExecutor.release();
                }
                if (error) {
                    throw error;
                }
            }
            return result;
        });
    }
    executeList(queries, options) {
        return __awaiter(this, void 0, void 0, function* () {
            const results = [];
            if (options.tryAllCan) {
                for (const query of queries) {
                    const queryExecutor = new queryExecutor_1.QueryExecutor(this.connectionFacade, this.languages, this.schemaFacade, this.expressions, options, this.helper, false);
                    try {
                        const result = yield queryExecutor.execute(query, {});
                        results.push(result);
                    }
                    catch (error) {
                        results.push({ error });
                    }
                    finally {
                        yield queryExecutor.release();
                    }
                }
            }
            else {
                yield this.transaction(options, function (tr) {
                    return __awaiter(this, void 0, void 0, function* () {
                        for (const query of queries) {
                            const result = yield tr.execute(query);
                            results.push({ result });
                        }
                    });
                });
            }
            return results;
        });
    }
    /**
 * Create a transaction
 * @param source Database name
 * @param callback Code to be executed in transaction
 */
    transaction(options, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            const queryExecutor = new queryExecutor_1.QueryExecutor(this.connectionFacade, this.languages, this.schemaFacade, this.expressions, options, this.helper, true);
            let error;
            try {
                const transaction = new domain_1.Transaction(queryExecutor);
                yield callback(transaction);
                yield queryExecutor.commit();
            }
            catch (_error) {
                error = _error;
                yield queryExecutor.rollback();
            }
            finally {
                yield queryExecutor.release();
            }
            if (error) {
                throw error;
            }
        });
    }
}
exports.ExecutorImpl = ExecutorImpl;
//# sourceMappingURL=executor.js.map