"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NoSqlDDLBuilderAdapter = void 0;
/* eslint-disable @typescript-eslint/no-unused-vars */
const domain_1 = require("../../../../schema/domain");
const domain_2 = require("../../../../query/domain");
const DDLBuilderAdapter_1 = require("../base/DDLBuilderAdapter");
class NoSqlDDLBuilderAdapter extends DDLBuilderAdapter_1.DDLBuilderAdapter {
    truncateEntity(entity) {
        // https://www.codegrepper.com/code-examples/c/truncate+collection+MongoDB
        return new domain_2.Query({ action: domain_1.SentenceAction.truncateEntity, dialect: this.source.dialect, source: this.source.name, sentence: '', entity: entity.name });
    }
    createEntity(entity) {
        return new domain_2.Query({ action: domain_1.SentenceAction.createEntity, dialect: this.source.dialect, source: this.source.name, sentence: '', entity: entity.name });
    }
    createFk(_entity, _relation) {
        return undefined;
    }
    createSequence(entity) {
        // https://www.tutorialspoint.com/MongoDB/mongodb_autoincrement_sequence.htm
        const sentence = `{ "_id" : "${this.dialect.delimiter(entity.sequence)}", "sequence_value": 1 }`;
        return new domain_2.Query({ action: domain_1.SentenceAction.createSequence, dialect: this.source.dialect, source: this.source.name, sentence, entity: entity.name });
    }
    createIndex(entity, index) {
        const columns = [];
        for (const field of index.fields) {
            const propertyMapping = entity.properties.find(p => p.name === field);
            columns.push(this.dialect.delimiter(propertyMapping.mapping));
        }
        const properties = {};
        for (const i in columns) {
            properties[columns[i]] = 1;
        }
        const sentence = JSON.stringify({
            properties,
            options: { name: this.dialect.delimiter(entity.mapping + '_' + index.name) }
        });
        return new domain_2.Query({ action: domain_1.SentenceAction.createIndex, dialect: this.source.dialect, source: this.source.name, sentence, entity: entity.name });
    }
    alterProperty(_entity, _property) {
        return undefined;
    }
    addProperty(_entity, _property) {
        return undefined;
    }
    addPk(entity, primaryKey) {
        const columns = [];
        for (const primaryKeyItem of primaryKey) {
            const property = entity.properties.find(p => p.name === primaryKeyItem);
            columns.push(this.dialect.delimiter(property.mapping));
        }
        const properties = {};
        for (const i in columns) {
            if (columns[i] !== '_id') {
                properties[columns[i]] = 1;
            }
        }
        const sentence = JSON.stringify({
            properties,
            options: { name: this.dialect.delimiter(entity.mapping + '_PK'), unique: true }
        });
        return new domain_2.Query({ action: domain_1.SentenceAction.addPk, dialect: this.source.dialect, source: this.source.name, sentence, entity: entity.name });
    }
    addUk(entity, uniqueKey) {
        // https://www.MongoDB.com/docs/drivers/node/current/fundamentals/indexes/#:~:text=By%20default%2C%20MongoDB%20creates%20a,the%20unique%20option%20to%20true%20.
        const columns = [];
        for (const uniqueKeyItem of uniqueKey) {
            const property = entity.properties.find(p => p.name === uniqueKeyItem);
            columns.push(this.dialect.delimiter(property.mapping));
        }
        const properties = {};
        for (const i in columns) {
            properties[columns[i]] = 1;
        }
        const sentence = JSON.stringify({
            properties,
            options: { name: this.dialect.delimiter(entity.mapping + '_UK'), unique: true }
        });
        return new domain_2.Query({ action: domain_1.SentenceAction.addUk, dialect: this.source.dialect, source: this.source.name, sentence, entity: entity.name });
    }
    addFk(_entity, _relation) {
        return undefined;
    }
    dropEntity(entity) {
        return new domain_2.Query({ action: domain_1.SentenceAction.dropEntity, dialect: this.source.dialect, source: this.source.name, sentence: '', entity: entity.name });
    }
    dropProperty(_entity, _property) {
        return undefined;
    }
    dropPk(entity) {
        // https://www.MongoDB.com/docs/manual/reference/method/db.collection.dropIndex/
        const sentence = this.dialect.delimiter(entity.mapping + '_PK');
        return new domain_2.Query({ action: domain_1.SentenceAction.dropPk, dialect: this.source.dialect, source: this.source.name, sentence, entity: entity.name });
    }
    dropUk(entity) {
        // https://www.MongoDB.com/docs/manual/reference/method/db.collection.dropIndex/
        const sentence = this.dialect.delimiter(entity.mapping + '_UK');
        return new domain_2.Query({ action: domain_1.SentenceAction.dropUk, dialect: this.source.dialect, source: this.source.name, sentence, entity: entity.name });
    }
    setNull(_entity, _relation) {
        return undefined;
    }
    dropFk(_entity, _relation) {
        return undefined;
    }
    dropIndex(entity, index) {
        // https://www.MongoDB.com/docs/manual/reference/method/db.collection.dropIndex/
        const sentence = this.dialect.delimiter(entity.mapping + '_' + index.name);
        return new domain_2.Query({ action: domain_1.SentenceAction.dropIndex, dialect: this.source.dialect, source: this.source.name, sentence, entity: entity.name });
    }
    dropSequence(entity) {
        const sentence = JSON.stringify({
            _id: this.dialect.delimiter(entity.sequence)
        });
        return new domain_2.Query({ action: domain_1.SentenceAction.dropSequence, dialect: this.source.dialect, source: this.source.name, sentence, entity: entity.name });
    }
}
exports.NoSqlDDLBuilderAdapter = NoSqlDDLBuilderAdapter;
//# sourceMappingURL=ddlBuilder.js.map