"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Queryable = exports.ModificableClauses = exports.IncludeAction = exports.FilterAction = exports.FilterClauses = exports.IncludeClauses = exports.FilterIncludeClauses = exports.HavingClauses = exports.Map2Clauses = exports.MapClauses = exports.PageClauses = exports.QueryAction = void 0;
class QueryAction {
    constructor(actions, expression) {
        this.actions = actions;
        this.expression = expression;
    }
    execute(data) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.actions.execute(this.expression, data);
        });
    }
    normalize() {
        return this.actions.normalize(this.expression);
    }
    model() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.actions.model(this.expression);
        });
    }
    constraints() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.actions.constraints(this.expression);
        });
    }
    parameters() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.actions.parameters(this.expression);
        });
    }
    sentence() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.actions.getInfo(this.expression);
        });
    }
    metadata() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.actions.metadata(this.expression);
        });
    }
}
exports.QueryAction = QueryAction;
class PageClauses extends QueryAction {
    /**  */
    page(page, records) {
        return new QueryAction(this.actions, `${this.expression}.page(${page},${records})`);
    }
}
exports.PageClauses = PageClauses;
class MapClauses extends PageClauses {
    /**  */
    sort(predicate) {
        return new PageClauses(this.actions, `${this.expression}.sort(${predicate.toString()})`);
    }
}
exports.MapClauses = MapClauses;
class Map2Clauses extends QueryAction {
    /**  */
    sort(predicate) {
        return new PageClauses(this.actions, `${this.expression}.sort(${predicate.toString()})`);
    }
}
exports.Map2Clauses = Map2Clauses;
class HavingClauses extends MapClauses {
    /**  */
    map(predicate) {
        return new MapClauses(this.actions, `${this.expression}.map(${predicate.toString()})`);
    }
    /**  */
    first(predicate) {
        return new Map2Clauses(this.actions, `${this.expression}.first(${predicate.toString()})`);
    }
    /**  */
    last(predicate) {
        return new Map2Clauses(this.actions, `${this.expression}.last(${predicate.toString()})`);
    }
    /**  */
    distinct(predicate) {
        return new MapClauses(this.actions, `${this.expression}.distinct(${predicate.toString()})`);
    }
}
exports.HavingClauses = HavingClauses;
class FilterIncludeClauses extends HavingClauses {
    /**  */
    having(predicate) {
        return new HavingClauses(this.actions, `${this.expression}.having(${predicate.toString()})`);
    }
}
exports.FilterIncludeClauses = FilterIncludeClauses;
class IncludeClauses extends HavingClauses {
    /**  */
    filter(predicate) {
        return new FilterIncludeClauses(this.actions, `${this.expression}.filter(${predicate.toString()})`);
    }
    /**  */
    having(predicate) {
        return new HavingClauses(this.actions, `${this.expression}.having(${predicate.toString()})`);
    }
}
exports.IncludeClauses = IncludeClauses;
class FilterClauses extends HavingClauses {
    /**  */
    include(predicate) {
        return new IncludeClauses(this.actions, `${this.expression}.include(${predicate.toString()})`);
    }
    /**  */
    having(predicate) {
        return new HavingClauses(this.actions, `${this.expression}.having(${predicate.toString()})`);
    }
}
exports.FilterClauses = FilterClauses;
class FilterAction extends QueryAction {
    /**  */
    filter(predicate) {
        return new QueryAction(this.actions, `${this.expression}.filter(${predicate.toString()})`);
    }
}
exports.FilterAction = FilterAction;
class IncludeAction extends QueryAction {
    /**  */
    include(predicate) {
        return new QueryAction(this.actions, `${this.expression}.include(${predicate.toString()})`);
    }
}
exports.IncludeAction = IncludeAction;
class ModificableClauses extends QueryAction {
    /**  */
    filter(predicate) {
        return new FilterClauses(this.actions, `${this.expression}.filter(${predicate.toString()})`);
    }
    /**  */
    include(predicate) {
        return new IncludeClauses(this.actions, `${this.expression}.include(${predicate.toString()})`);
    }
}
exports.ModificableClauses = ModificableClauses;
class Queryable extends HavingClauses {
    /**  */
    filter(predicate) {
        return new FilterClauses(this.actions, `${this.expression}.filter(${predicate.toString()})`);
    }
    /**  */
    include(predicate) {
        return new IncludeClauses(this.actions, `${this.expression}.include(${predicate.toString()})`);
    }
    /**  */
    having(predicate) {
        return new HavingClauses(this.actions, `${this.expression}.having(${predicate.toString()})`);
    }
    /**  */
    // insert (predicate?: T): ModificableClauses<T>
    insert(predicate) {
        if (predicate) {
            return new ModificableClauses(this.actions, `${this.expression}.insert(${predicate !== undefined ? JSON.stringify(predicate) : ''})`);
        }
        else {
            return new ModificableClauses(this.actions, `${this.expression}.insert()`);
        }
    }
    /**  */
    bulkInsert(value) {
        return new ModificableClauses(this.actions, `${this.expression}.bulkInsert(${value !== undefined ? JSON.stringify(value) : ''})`);
    }
    /**  */
    update(predicate) {
        if (predicate) {
            return new ModificableClauses(this.actions, `${this.expression}.update(${predicate.toString()})`);
        }
        else {
            return new ModificableClauses(this.actions, `${this.expression}.update()`);
        }
    }
    /**  */
    updateAll(predicate) {
        return new IncludeAction(this.actions, `${this.expression}.updateAll(${predicate.toString()})`);
    }
    /**  */
    delete(predicate) {
        if (predicate) {
            return new ModificableClauses(this.actions, `${this.expression}.delete(${predicate.toString()})`);
        }
        else {
            return new ModificableClauses(this.actions, `${this.expression}.delete()`);
        }
    }
    /**  */
    deleteAll() {
        return new IncludeAction(this.actions, `${this.expression}.deleteAll()`);
    }
}
exports.Queryable = Queryable;
//# sourceMappingURL=queryable.js.map