"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SchemaFacade = void 0;
const domain_1 = require("../domain");
class SchemaFacade {
    constructor(workspace, source, domain, mapping, stage, view, schemaService, routeService, extender, createSchema, loadSchema, getSchema, completeSchema) {
        this.workspace = workspace;
        this.source = source;
        this.domain = domain;
        this.mapping = mapping;
        this.stage = stage;
        this.view = view;
        this.schemaService = schemaService;
        this.routeService = routeService;
        this.extender = extender;
        this.createSchema = createSchema;
        this.loadSchema = loadSchema;
        this.getSchema = getSchema;
        this.completeSchema = completeSchema;
        this.schema = this.schemaService.newSchema();
    }
    evalDataSourceRule(rule, clauseInfo) {
        return this.routeService.eval(rule, clauseInfo);
    }
    getSource(clauseInfo, stage) {
        return this.routeService.getSource(clauseInfo, stage);
    }
    create() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.createSchema.create();
        });
    }
    get(source) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.getSchema.get(source);
        });
    }
    initialize(source) {
        return __awaiter(this, void 0, void 0, function* () {
            const schema = yield this.getSchema.get(source);
            if (schema === null) {
                throw new domain_1.SchemaError(`Schema: ${source} not supported`);
            }
            this.completeSchema.complete(schema);
            this.schema = this.loadSchema.load(schema);
            return this.schema;
        });
    }
    complete(schema) {
        this.extender.complete(schema);
    }
}
exports.SchemaFacade = SchemaFacade;
//# sourceMappingURL=facade.js.map