"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SchemaFacadeBuilder = void 0;
const application_1 = require("../application");
const fileSchemaReader_1 = require("./fileSchemaReader");
const schemaFileHelper_1 = require("./schemaFileHelper");
class SchemaFacadeBuilder {
    // eslint-disable-next-line no-useless-constructor
    constructor(expressions, helper) {
        this.expressions = expressions;
        this.helper = helper;
    }
    build(workspace) {
        const source = new application_1.DataSourceConfigService();
        const model = new application_1.DomainConfigService();
        const mapping = new application_1.MappingsConfigService();
        const stage = new application_1.StageConfigService();
        const view = new application_1.ViewsConfigService();
        const schemaService = new application_1.SchemaService();
        const routeService = new application_1.RouteService(stage, this.expressions);
        const extender = new application_1.SchemaExtender(this.expressions, this.helper);
        const loadSchema = new application_1.LoadSchema(source, model, mapping, stage, view, extender, this.helper);
        const createSchema = new application_1.CreateSchema(schemaService);
        const getSchema = new application_1.GetSchema(new fileSchemaReader_1.FileSchemaReader(new schemaFileHelper_1.SchemaFileHelper(this.helper), this.helper));
        const completeSchema = new application_1.CompleteSchema(schemaService);
        return new application_1.SchemaFacade(workspace, source, model, mapping, stage, view, schemaService, routeService, extender, createSchema, loadSchema, getSchema, completeSchema);
    }
}
exports.SchemaFacadeBuilder = SchemaFacadeBuilder;
//# sourceMappingURL=facadeBuilder.js.map