"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable no-template-curly-in-string */
const __1 = require("../../..");
beforeAll(() => __awaiter(void 0, void 0, void 0, function* () {
    require('dotenv').config({ path: './config/countries.env' });
    yield __1.orm.init('./config/countries.yaml');
}));
describe('sort', () => {
    const context = JSON.parse('{}');
    test('normalize', () => {
        expect(__1.orm.normalize('Countries.map(p=> {region:p.region,countries:count(1)}).sort(p=> p.countries)')).toStrictEqual('Countries.map(p=>{region:p.region,countries:count(1)}).sort(p=>asc(p.countries))');
        expect(__1.orm.normalize('Countries.filter(p=> p.subregion == "South America").map(p=> p.iso3).sort(p=> desc(iso3))')).toStrictEqual('Countries.map(p=>{iso3:p.iso3}).filter(p=>(p.subregion==South America)).sort(p=>desc(iso3))');
        expect(__1.orm.normalize('Countries.map(p=> {region:p.region,max:max(p.latitude)}).sort(p=> asc(p.max))')).toStrictEqual('Countries.map(p=>{region:p.region,max:max(p.latitude)}).sort(p=>asc(p.max))');
    });
    test('model', () => {
        expect(__1.orm.model('Countries.map(p=> {region:p.region,countries:count(1)}).sort(p=> p.countries)')).toStrictEqual([{ 'name': 'region', 'type': 'string' }, { 'name': 'countries', 'type': 'integer' }]);
        expect(__1.orm.model('Countries.filter(p=> p.subregion == "South America").map(p=> p.iso3).sort(p=> desc(iso3))')).toStrictEqual([{ 'name': 'iso3', 'type': 'string' }]);
        expect(__1.orm.model('Countries.map(p=> {region:p.region,max:max(p.latitude)}).sort(p=> asc(p.max))')).toStrictEqual([{ 'name': 'region', 'type': 'string' }, { 'name': 'max', 'type': 'any' }]);
    });
    test('parameters', () => {
        expect(__1.orm.parameters('Countries.map(p=> {region:p.region,countries:count(1)}).sort(p=> p.countries)')).toStrictEqual([]);
        expect(__1.orm.parameters('Countries.filter(p=> p.subregion == "South America").map(p=> p.iso3).sort(p=> desc(iso3))')).toStrictEqual([{ 'name': 'iso3', 'type': 'any' }]);
        expect(__1.orm.parameters('Countries.map(p=> {region:p.region,max:max(p.latitude)}).sort(p=> asc(p.max))')).toStrictEqual([]);
    });
    test('constraints', () => {
        expect(__1.orm.constraints('Countries.map(p=> {region:p.region,countries:count(1)}).sort(p=> p.countries)')).toStrictEqual({ "entity": "Countries", "constraints": [] });
        expect(__1.orm.constraints('Countries.filter(p=> p.subregion == "South America").map(p=> p.iso3).sort(p=> desc(iso3))')).toStrictEqual({ "entity": "Countries", "constraints": [] });
        expect(__1.orm.constraints('Countries.map(p=> {region:p.region,max:max(p.latitude)}).sort(p=> asc(p.max))')).toStrictEqual({ "entity": "Countries", "constraints": [] });
    });
    test('getInfo', () => {
        expect(__1.orm.getInfo('Countries.map(p=> {region:p.region,countries:count(1)}).sort(p=> p.countries)', { stage: 'stage1' })).toStrictEqual({ "entity": "Countries", "dialect": "MySQL", "source": "dataSource1", "sentence": "SELECT c.region AS region, COUNT(1) AS countries FROM Countries c  GROUP BY c.region ORDER BY countries asc ", "children": [] });
        expect(__1.orm.getInfo('Countries.filter(p=> p.subregion == "South America").map(p=> p.iso3).sort(p=> desc(iso3))', { stage: 'stage1' })).toStrictEqual({ "entity": "Countries", "dialect": "MySQL", "source": "dataSource1", "sentence": "SELECT c.iso3 AS iso3 FROM Countries c  WHERE c.subregion = 'South America' ORDER BY ? desc ", "children": [] });
        expect(__1.orm.getInfo('Countries.map(p=> {region:p.region,max:max(p.latitude)}).sort(p=> asc(p.max))', { stage: 'stage1' })).toStrictEqual({ "entity": "Countries", "dialect": "MySQL", "source": "dataSource1", "sentence": "SELECT c.region AS region, MAX(c.latitude) AS max FROM Countries c  GROUP BY c.region ORDER BY max asc ", "children": [] });
    });
});
//# sourceMappingURL=sort.test.js.map